pub trait Discv5ApiClient: ClientT {
    fn node_info<'life0, 'async_trait>(
        &'life0 self
    ) -> Pin<Box<dyn Future<Output = RpcResult<NodeInfo>> + Send + 'async_trait>>
    where
        Self: Sync + 'async_trait,
        'life0: 'async_trait
, { ... } fn update_node_info<'life0, 'async_trait>(
        &'life0 self,
        socket_addr: String,
        is_tcp: Option<bool>
    ) -> Pin<Box<dyn Future<Output = RpcResult<NodeInfo>> + Send + 'async_trait>>
    where
        Self: Sync + 'async_trait,
        'life0: 'async_trait
, { ... } fn routing_table_info<'life0, 'async_trait>(
        &'life0 self
    ) -> Pin<Box<dyn Future<Output = RpcResult<RoutingTableInfo>> + Send + 'async_trait>>
    where
        Self: Sync + 'async_trait,
        'life0: 'async_trait
, { ... } fn add_enr<'life0, 'async_trait>(
        &'life0 self,
        enr: Enr
    ) -> Pin<Box<dyn Future<Output = RpcResult<bool>> + Send + 'async_trait>>
    where
        Self: Sync + 'async_trait,
        'life0: 'async_trait
, { ... } fn get_enr<'life0, 'async_trait>(
        &'life0 self,
        node_id: NodeId
    ) -> Pin<Box<dyn Future<Output = RpcResult<Enr>> + Send + 'async_trait>>
    where
        Self: Sync + 'async_trait,
        'life0: 'async_trait
, { ... } fn delete_enr<'life0, 'async_trait>(
        &'life0 self,
        node_id: NodeId
    ) -> Pin<Box<dyn Future<Output = RpcResult<bool>> + Send + 'async_trait>>
    where
        Self: Sync + 'async_trait,
        'life0: 'async_trait
, { ... } fn lookup_enr<'life0, 'async_trait>(
        &'life0 self,
        node_id: NodeId,
        enr_seq: Option<u32>
    ) -> Pin<Box<dyn Future<Output = RpcResult<Enr>> + Send + 'async_trait>>
    where
        Self: Sync + 'async_trait,
        'life0: 'async_trait
, { ... } }
Client implementation for the Discv5Api RPC API.

Provided Methods

Returns ENR and Node ID information of the local discv5 node.

Update the socket address of the local node record.

Returns meta information about discv5 routing table.

Write an Ethereum Node Record to the routing table.

Fetch the latest ENR associated with the given node ID.

Delete Node ID from the routing table.

Fetch the ENR representation associated with the given Node ID and optional sequence number.

Implementors